# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/polvo/',
                'doc_host': 'https://lgvaz.github.io',
                'git_url': 'https://github.com/lgvaz/polvo/',
                'lib_path': 'polvo'},
  'syms': { 'polvo.classification.baseline.baseline': { 'polvo.classification.baseline.baseline.FastaiMetricWrapper': ( 'https://lgvaz.github.io/polvo/02b_classification.baseline.baseline.html#fastaimetricwrapper',
                                                                                                                        'https://github.com/lgvaz/polvo//blob/master/polvo/classification/baseline/baseline.py#L11'),
                                                        'polvo.classification.baseline.baseline.FastaiMetricWrapper.__init__': ( 'https://lgvaz.github.io/polvo/02b_classification.baseline.baseline.html#__init__',
                                                                                                                                 'https://github.com/lgvaz/polvo//blob/master/polvo/classification/baseline/baseline.py#L13'),
                                                        'polvo.classification.baseline.baseline.FastaiMetricWrapper.accumulate': ( 'https://lgvaz.github.io/polvo/02b_classification.baseline.baseline.html#accumulate',
                                                                                                                                   'https://github.com/lgvaz/polvo//blob/master/polvo/classification/baseline/baseline.py#L16'),
                                                        'polvo.classification.baseline.baseline.calculate_metrics': ( 'https://lgvaz.github.io/polvo/02b_classification.baseline.baseline.html#calculate_metrics',
                                                                                                                      'https://github.com/lgvaz/polvo//blob/master/polvo/classification/baseline/baseline.py#L21'),
                                                        'polvo.classification.baseline.baseline.fixed_probs': ( 'https://lgvaz.github.io/polvo/02b_classification.baseline.baseline.html#fixed_probs',
                                                                                                                'https://github.com/lgvaz/polvo//blob/master/polvo/classification/baseline/baseline.py#L37'),
                                                        'polvo.classification.baseline.baseline.random_probs': ( 'https://lgvaz.github.io/polvo/02b_classification.baseline.baseline.html#random_probs',
                                                                                                                 'https://github.com/lgvaz/polvo//blob/master/polvo/classification/baseline/baseline.py#L43')},
            'polvo.classification.explorer': { 'polvo.classification.explorer.DataExplorer': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#dataexplorer',
                                                                                               'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L12'),
                                               'polvo.classification.explorer.DataExplorer.__init__': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#__init__',
                                                                                                        'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L13'),
                                               'polvo.classification.explorer.DataExplorer._group_y': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#_group_y',
                                                                                                        'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L22'),
                                               'polvo.classification.explorer.DataExplorer.from_datasets': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#from_datasets',
                                                                                                             'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L54'),
                                               'polvo.classification.explorer.DataExplorer.most_common': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#most_common',
                                                                                                           'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L32'),
                                               'polvo.classification.explorer.DataExplorer.show_label': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#show_label',
                                                                                                          'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L41'),
                                               'polvo.classification.explorer.DataExplorer.show_label_id': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#show_label_id',
                                                                                                             'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L36'),
                                               'polvo.classification.explorer.DataExplorer.show_most_common': ( 'https://lgvaz.github.io/polvo/02a_classification.explorer.html#show_most_common',
                                                                                                                'https://github.com/lgvaz/polvo//blob/master/polvo/classification/explorer.py#L44')},
            'polvo.common': { 'polvo.common.get_image_grid': ( 'https://lgvaz.github.io/polvo/common.html#get_image_grid',
                                                               'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L13'),
                              'polvo.common.image_grid': ( 'https://lgvaz.github.io/polvo/common.html#image_grid',
                                                           'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L44'),
                              'polvo.common.image_size': ( 'https://lgvaz.github.io/polvo/common.html#image_size',
                                                           'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L53'),
                              'polvo.common.image_sizes_hist': ( 'https://lgvaz.github.io/polvo/common.html#image_sizes_hist',
                                                                 'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L58'),
                              'polvo.common.normalize_axes': ( 'https://lgvaz.github.io/polvo/common.html#normalize_axes',
                                                               'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L37'),
                              'polvo.common.one_batch_with_idxs': ( 'https://lgvaz.github.io/polvo/common.html#one_batch_with_idxs',
                                                                    'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L69'),
                              'polvo.common.show_grid': ( 'https://lgvaz.github.io/polvo/common.html#show_grid',
                                                          'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L32'),
                              'polvo.common.show_tfms': ( 'https://lgvaz.github.io/polvo/common.html#show_tfms',
                                                          'https://github.com/lgvaz/polvo//blob/master/polvo/common.py#L85')},
            'polvo.segmentation.core': { 'polvo.segmentation.core.SegmentationExplorer': ( 'https://lgvaz.github.io/polvo/segmentation.core.html#segmentationexplorer',
                                                                                           'https://github.com/lgvaz/polvo//blob/master/polvo/segmentation/core.py#L13'),
                                         'polvo.segmentation.core.SegmentationExplorer.__init__': ( 'https://lgvaz.github.io/polvo/segmentation.core.html#__init__',
                                                                                                    'https://github.com/lgvaz/polvo//blob/master/polvo/segmentation/core.py#L14'),
                                         'polvo.segmentation.core.SegmentationExplorer._group_y': ( 'https://lgvaz.github.io/polvo/segmentation.core.html#_group_y',
                                                                                                    'https://github.com/lgvaz/polvo//blob/master/polvo/segmentation/core.py#L22'),
                                         'polvo.segmentation.core.SegmentationExplorer.from_datasets': ( 'https://lgvaz.github.io/polvo/segmentation.core.html#from_datasets',
                                                                                                         'https://github.com/lgvaz/polvo//blob/master/polvo/segmentation/core.py#L50'),
                                         'polvo.segmentation.core.SegmentationExplorer.most_common_appearances': ( 'https://lgvaz.github.io/polvo/segmentation.core.html#most_common_appearances',
                                                                                                                   'https://github.com/lgvaz/polvo//blob/master/polvo/segmentation/core.py#L42'),
                                         'polvo.segmentation.core.SegmentationExplorer.most_common_pixels': ( 'https://lgvaz.github.io/polvo/segmentation.core.html#most_common_pixels',
                                                                                                              'https://github.com/lgvaz/polvo//blob/master/polvo/segmentation/core.py#L46')}}}